@@ -303,12 +303,6 @@ class Graphics3DBox(GraphicsBox):
                             light["target"][j] * boxscale[j] for j in range(3)
                         ]
 
-                # Rescale viewpoint
-                self.viewpoint = [
-                    vp * max([xmax - xmin, ymax - ymin, zmax - zmin])
-                    for vp in self.viewpoint
-                ]
-
             w = 0 if (xmin is None or xmax is None) else xmax - xmin
             h = 0 if (ymin is None or ymax is None) else ymax - ymin
 
@@ -394,6 +388,7 @@ class Graphics3DBox(GraphicsBox):
                 },
                 "lighting": self.lighting,
                 "viewpoint": self.viewpoint,
+                "protocol": "1.0",
             }
         )
 
@@ -601,7 +596,11 @@ currentlight=light(rgb(0.5,0.5,1), specular=red, (2,0,2), (2,2,2), (0,2,2));
 """.format(
             asy_number(width / 60),
             asy_number(height / 60),
-            self.viewpoint,
+            # Rescale viewpoint
+            [
+                vp * max([xmax - xmin, ymax - ymin, zmax - zmin])
+                for vp in self.viewpoint
+            ],
             asy,
             boundbox_asy,
         )
