@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-
 """
-Plotting
+Plotting Data
+
+Plotting functions take a function as a parameter and data, often a range of points, as another parameter, and plot or show the function applied to the data.
 """
 
 
