@@ -317,141 +317,6 @@ class Sequence(Builtin):
     """
 
 
-class Line(Builtin):
-    """
-    <dl>
-    <dt>'$Line'
-        <dd>holds the current input line number.
-    </dl>
-    >> $Line
-     = 1
-    >> $Line
-     = 2
-    >> $Line = 12;
-    >> 2 * 5
-     = 10
-    >> Out[13]
-     = 10
-    >> $Line = -1;
-     : Non-negative integer expected.
-    """
-
-    name = "$Line"
-
-
-class HistoryLength(Builtin):
-    """
-    <dl>
-    <dt>'$HistoryLength'
-        <dd>specifies the maximum number of 'In' and 'Out' entries.
-    </dl>
-    >> $HistoryLength
-     = 100
-    >> $HistoryLength = 1;
-    >> 42
-     = 42
-    >> %
-     = 42
-    >> %%
-     = %3
-    >> $HistoryLength = 0;
-    >> 42
-     = 42
-    >> %
-     = %7
-    """
-
-    name = "$HistoryLength"
-
-    rules = {
-        "$HistoryLength": "100",
-    }
-
-
-class In(Builtin):
-    """
-    <dl>
-    <dt>'In[$k$]'
-        <dd>gives the $k$th line of input.
-    </dl>
-    >> x = 1
-     = 1
-    >> x = x + 1
-     = 2
-    >> Do[In[2], {3}]
-    >> x
-     = 5
-    >> In[-1]
-     = 5
-    >> Definition[In]
-     = Attributes[In] = {Protected}
-     .
-     . In[6] = Definition[In]
-     .
-     . In[5] = In[-1]
-     .
-     . In[4] = x
-     .
-     . In[3] = Do[In[2], {3}]
-     .
-     . In[2] = x = x + 1
-     .
-     . In[1] = x = 1
-    """
-
-    rules = {
-        "In[k_Integer?Negative]": "In[$Line + k]",
-    }
-
-
-class Out(Builtin):
-    """
-    <dl>
-    <dt>'Out[$k$]'
-    <dt>'%$k$'
-        <dd>gives the result of the $k$th input line.
-    <dt>'%', '%%', etc.
-        <dd>gives the result of the previous input line, of the line before the previous input line, etc.
-    </dl>
-
-    >> 42
-     = 42
-    >> %
-     = 42
-    >> 43;
-    >> %
-     = 43
-    >> 44
-     = 44
-    >> %1
-     = 42
-    >> %%
-     = 44
-    >> Hold[Out[-1]]
-     = Hold[%]
-    >> Hold[%4]
-     = Hold[%4]
-    >> Out[0]
-     = Out[0]
-
-    #> 10
-     = 10
-    #> Out[-1] + 1
-     = 11
-    #> Out[] + 1
-     = 12
-    """
-
-    rules = {
-        "Out[k_Integer?Negative]": "Out[$Line + k]",
-        "Out[]": "Out[$Line - 1]",
-        "MakeBoxes[Out[k_Integer?((-10 <= # < 0)&)],"
-        "    f:StandardForm|TraditionalForm|InputForm|OutputForm]": r'StringJoin[ConstantArray["%%", -k]]',
-        "MakeBoxes[Out[k_Integer?Positive],"
-        "    f:StandardForm|TraditionalForm|InputForm|OutputForm]": r'"%%" <> ToString[k]',
-    }
-
-
 class Quit(Builtin):
     """
     <dl>
