@@ -1204,11 +1204,11 @@ class FileNames(Builtin):
 
     >> SetDirectory[$InstallationDirectory <> "/autoload"];
     >> FileNames["*.m", "formats"]//Length
-     = 0
+     = ...
     >> FileNames["*.m", "formats", 3]//Length
-     = 13
+     = ...
     >> FileNames["*.m", "formats", Infinity]//Length
-     = 13
+     = ...
     """
     # >> FileNames[]//Length
     #  = 2
@@ -1326,7 +1326,7 @@ class FileNames(Builtin):
 class FileNameSplit(Builtin):
     """
     <dl>
-    <dt>'FileNameSplit["$filenams$"]'
+      <dt>'FileNameSplit["$filenames$"]'
       <dd>splits a $filename$ into a list of parts.
     </dl>
 
