@@ -210,9 +210,12 @@ def _extract_graphics(graphics, format, evaluation):
 class Show(Builtin):
     """
     <dl>
-      <dt>'Show[$graphics$, $options$]'
-      <dd>shows graphics with the specified options added.
+    <dt>'Show[$graphics$, $options$]'
+        <dd>shows a list of graphics with the specified options added.
     </dl>
+
+    >> Show[{Plot[x, {x, 0, 10}], ListPlot[{1,2,3}]}]
+     = ...
     """
 
     options = GRAPHICS_OPTIONS
@@ -751,14 +754,17 @@ class RegularPolygon(Builtin):
 class Arrow(Builtin):
     """
     <dl>
-    <dt>'Arrow[{$p1$, $p2$}]'
-        <dd>represents a line from $p1$ to $p2$ that ends with an arrow at $p2$.
-    <dt>'Arrow[{$p1$, $p2$}, $s$]'
-        <dd>represents a line with arrow that keeps a distance of $s$ from $p1$
-        and $p2$.
-    <dt>'Arrow[{$point_1$, $point_2$}, {$s1$, $s2$}]'
-        <dd>represents a line with arrow that keeps a distance of $s1$ from $p1$
-        and a distance of $s2$ from $p2$.
+      <dt>'Arrow[{$p1$, $p2$}]'
+      <dd>represents a line from $p1$ to $p2$ that ends with an arrow at $p2$.
+
+      <dt>'Arrow[{$p1$, $p2$}, $s$]'
+      <dd>represents a line with arrow that keeps a distance of $s$ from $p1$ and $p2$.
+
+      <dt>'Arrow[{$point_1$, $point_2$}, {$s1$, $s2$}]'
+      <dd>represents a line with arrow that keeps a distance of $s1$ from $p1$ and a distance of $s2$ from $p2$.
+
+      <dt>'Arrow[{$point_1$, $point_2$}, {$s1$, $s2$}]'
+      <dd>represents a line with arrow that keeps a distance of $s1$ from $p1$ and a distance of $s2$ from $p2$.
     </dl>
 
     >> Graphics[Arrow[{{0,0}, {1,1}}]]
@@ -767,6 +773,11 @@ class Arrow(Builtin):
     >> Graphics[{Circle[], Arrow[{{2, 1}, {0, 0}}, 1]}]
     = -Graphics-
 
+    Arrows can also be drawn in 3D by giving poing in three dimensions:
+
+    >> Graphics3D[Arrow[{{1, 1, -1}, {2, 2, 0}, {3, 3, -1}, {4, 4, 0}}]]
+     = -Graphics3D-
+
     Keeping distances may happen across multiple segments:
 
     >> Table[Graphics[{Circle[], Arrow[Table[{Cos[phi],Sin[phi]},{phi,0,2*Pi,Pi/2}],{d, d}]}],{d,0,2,0.5}]
@@ -1361,20 +1372,21 @@ class Large(Builtin):
 
 element_heads = frozenset(
     system_symbols(
-        "Rectangle",
-        "Disk",
-        "Line",
         "Arrow",
-        "FilledCurve",
         "BezierCurve",
-        "Point",
         "Circle",
-        "Polygon",
-        "RegularPolygon",
+        "Cylinder",
+        "Disk",
+        "FilledCurve",
         "Inset",
-        "Text",
+        "Line",
+        "Point",
+        "Polygon",
+        "Rectangle",
+        "RegularPolygon",
         "Sphere",
         "Style",
+        "Text",
     )
 )
 
