@@ -1,15 +1,16 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+# FIXME: combine with same thing in Mathics core
 """
-Does 3 things which can either be done independently or
+Does 2 things which can either be done independently or
 as a pipeline:
 
 1. Extracts tests and runs them from static mdoc files and docstrings from Mathics built-in functions
 2. Creates/updates internal documentation data
-3. It writes the LaTeX file containing the entire User Manual
 """
 
 import os
+import os.path as osp
 import pickle
 import re
 import sys
@@ -26,6 +27,7 @@ from mathics.builtin import builtins_dict
 
 from mathics import version_string
 from mathics import settings
+from mathics.doc.common_doc import MathicsMainDocumentation
 
 builtins = builtins_dict()
 
@@ -39,7 +41,7 @@ sep = "-" * 70 + "\n"
 
 # Global variables
 definitions = None
-documentation = None
+documentation = MathicsMainDocumentation()
 check_partial_enlapsed_time = False
 logfile = None
 
@@ -48,7 +50,6 @@ MAX_TESTS = 100000  # Number than the total number of tests
 
 
 def print_and_log(*args):
-    global logfile
     a = [a.decode("utf-8") if isinstance(a, bytes) else a for a in args]
     string = "".join(a)
     print(string)
@@ -88,7 +89,7 @@ def test_case(test, tests, index=0, subindex=0, quiet=False, section=None):
         print_and_log(
             f"""{sep}Test failed: {section} in {part} / {chapter}
 {part}
-n{why}
+{why}
 """.encode(
                 "utf-8"
             )
@@ -192,21 +193,24 @@ def test_tests(
 
 
 # FIXME: move this to common routine
-def create_output(tests, output, format="tex"):
+def create_output(tests, doc_data, format="tex"):
     definitions.reset_user_definitions()
     for test in tests.tests:
         if test.private:
             continue
         key = test.key
         evaluation = Evaluation(
-            definitions, format=format, catch_interrupt=False, output=TestOutput()
+            definitions, format=format, catch_interrupt=True, output=TestOutput()
         )
-        result = evaluation.parse_evaluate(test.test)
+        try:
+            result = evaluation.parse_evaluate(test.test)
+        except:  # noqa
+            result = None
         if result is None:
             result = []
         else:
             result = [result.get_data()]
-        output[key] = {
+        doc_data[key] = {
             "query": test.test,
             "results": result,
         }
@@ -221,11 +225,18 @@ def test_chapters(
 ):
     failed = 0
     index = 0
-    print(f'Testing chapter(s): {", ".join(chapters)}')
-    output_tex = load_doc_data() if reload else {}
+    chapter_names = ", ".join(chapters)
+    print(f"Testing chapter(s): {chapter_names}")
+    output_data = load_doc_data() if reload else {}
+    prev_key = []
     for tests in documentation.get_tests():
         if tests.chapter in chapters:
             for test in tests.tests:
+                key = list(test.key)[1:-1]
+                if prev_key != key:
+                    prev_key = key
+                    print(f'Testing section: {" / ".join(key)}')
+                    index = 0
                 if test.ignore:
                     continue
                 index += 1
@@ -234,13 +245,15 @@ def test_chapters(
                     if stop_on_failure:
                         break
             if generate_output and failed == 0:
-                create_output(tests, output_tex)
+                create_output(tests, output_data)
 
     print()
-    if failed > 0:
+    if index == 0:
+        print_and_log(f"No chapters found named {chapter_names}.")
+    elif failed > 0:
         print_and_log("%d test%s failed." % (failed, "s" if failed != 1 else ""))
     else:
-        print_and_log("OK")
+        print_and_log("All tests passed.")
 
 
 def test_sections(
@@ -252,12 +265,19 @@ def test_sections(
 ):
     failed = 0
     index = 0
-    print(f'Testing section(s): {", ".join(sections)}')
+    section_names = ", ".join(sections)
+    print(f"Testing section(s): {section_names}")
     sections |= {"$" + s for s in sections}
-    output_tex = load_doc_data() if reload else {}
+    output_data = load_doc_data() if reload else {}
+    prev_key = []
     for tests in documentation.get_tests():
         if tests.section in sections:
             for test in tests.tests:
+                key = list(test.key)[1:-1]
+                if prev_key != key:
+                    prev_key = key
+                    print(f'Testing section: {" / ".join(key)}')
+                    index = 0
                 if test.ignore:
                     continue
                 index += 1
@@ -266,28 +286,32 @@ def test_sections(
                     if stop_on_failure:
                         break
             if generate_output and failed == 0:
-                create_output(tests, output_tex)
+                create_output(tests, output_data)
 
     print()
-    if failed > 0:
+    if index == 0:
+        print_and_log(f"No sections found named {section_names}.")
+    elif failed > 0:
         print_and_log("%d test%s failed." % (failed, "s" if failed != 1 else ""))
     else:
-        print_and_log("OK")
+        print_and_log("All tests passed.")
+    if generate_output and (failed == 0):
+        save_doc_data(output_data)
 
 
 def open_ensure_dir(f, *args, **kwargs):
     try:
         return open(f, *args, **kwargs)
     except (IOError, OSError):
-        d = os.path.dirname(f)
-        if d and not os.path.exists(d):
+        d = osp.dirname(f)
+        if d and not osp.exists(d):
             os.makedirs(d)
         return open(f, *args, **kwargs)
 
 
 def test_all(
     quiet=False,
-    generate_output=False,
+    generate_output=True,
     stop_on_failure=False,
     start_at=0,
     count=MAX_TESTS,
@@ -295,18 +319,21 @@ def test_all(
     doc_even_if_error=False,
     excludes=[],
 ):
-    global documentation
     if not quiet:
         print(f"Testing {version_string}")
 
     if generate_output:
         if texdatafolder is None:
-            texdatafolder = settings.DOC_TEX_DATA_PATH
+            texdatafolder = osp.dirname(
+                settings.get_doc_tex_data_path(
+                    should_be_readable=False, create_parent=True
+                )
+            )
     try:
         index = 0
         total = failed = skipped = 0
         failed_symbols = set()
-        output_tex = {}
+        output_data = {}
         for tests in documentation.get_tests():
             sub_total, sub_failed, sub_skipped, symbols, index = test_tests(
                 tests,
@@ -318,7 +345,7 @@ def test_all(
                 excludes=excludes,
             )
             if generate_output:
-                create_output(tests, output_tex)
+                create_output(tests, output_data)
             total += sub_total
             failed += sub_failed
             skipped += sub_skipped
@@ -352,7 +379,7 @@ def test_all(
             print_and_log("  - %s in %s / %s" % (section, part, chapter))
 
     if generate_output and (failed == 0 or doc_even_if_error):
-        save_doc_data(output_tex)
+        save_doc_data(output_data)
         return True
 
     if failed == 0:
@@ -363,58 +390,46 @@ def test_all(
 
 
 def load_doc_data():
-    print(f"Loading LaTeX internal data from {settings.DOC_TEX_DATA_PATH}")
-    with open_ensure_dir(settings.DOC_TEX_DATA_PATH, "rb") as tex_data_file:
-        return pickle.load(tex_data_file)
+    doc_tex_data_path = settings.get_doc_tex_data_path(should_be_readable=True)
+    print(f"Loading internal document data from {doc_tex_data_path}")
+    with open_ensure_dir(doc_tex_data_path, "rb") as doc_data_file:
+        return pickle.load(doc_data_file)
 
 
-def save_doc_data(output_tex):
-    print(f"Writing LaTeX internal data to {settings.DOC_TEX_DATA_PATH}")
-    with open_ensure_dir(settings.DOC_TEX_DATA_PATH, "wb") as output_file:
-        pickle.dump(output_tex, output_file, 4)
+def save_doc_data(output_data):
+    doc_tex_data_path = settings.get_doc_tex_data_path(
+        should_be_readable=False, create_parent=True
+    )
+    print(f"Writing internal document data to {doc_tex_data_path}")
+    with open(settings.DOC_USER_TEX_DATA_PATH, "wb") as output_file:
+        pickle.dump(output_data, output_file, 4)
 
 
 def extract_doc_from_source(quiet=False, reload=False):
     """
-    Write internal (pickled) TeX doc mdoc files and example data in docstrings.
+    Write internal (pickled) doc files and example data in docstrings.
     """
     if not quiet:
         print(f"Extracting internal doc data for {version_string}")
         print("This may take a while...")
 
     try:
-        output_tex = load_doc_data() if reload else {}
+        output_data = load_doc_data() if reload else {}
         for tests in documentation.get_tests():
-            create_output(tests, output_tex)
+            create_output(tests, output_data)
     except KeyboardInterrupt:
         print("\nAborted.\n")
         return
 
     print("done.\n")
-    save_doc_data(output_tex)
-
-
-def write_latex():
-    print(f"Load data {settings.DOC_TEX_DATA_PATH}")
-    with open_ensure_dir(settings.DOC_TEX_DATA_PATH, "rb") as output_file:
-        output_tex = pickle.load(output_file)
-
-    print(f"Write LaTeX {settings.DOC_LATEX_FILE}")
-    with open_ensure_dir(settings.DOC_LATEX_FILE, "wb") as doc:
-        content = documentation.latex(output_tex)
-        content = content.encode("utf-8")
-        doc.write(content)
+    save_doc_data(output_data)
 
 
 def main():
-    from mathics.doc import documentation as main_mathics_documentation
-
     global definitions
-    global documentation
     global logfile
     global check_partial_enlapsed_time
     definitions = Definitions(add_builtin=True)
-    documentation = main_mathics_documentation
 
     parser = ArgumentParser(description="Mathics test suite.", add_help=False)
     parser.add_argument(
@@ -475,33 +490,20 @@ def main():
         "-o",
         dest="output",
         action="store_true",
-        help="generate LaTeX pickled internal data",
+        help="generate pickled internal document data",
     )
     parser.add_argument(
         "--doc-only",
         dest="doc_only",
         action="store_true",
-        help="generate LaTeX pickled internal data without running tests; Can't be used with --section or --reload.",
-    )
-    parser.add_argument(
-        "--latex-only",
-        dest="latex_only",
-        action="store_true",
-        help="generate LaTeX output from internal data without running tests; assumes --reload",
+        help="generate pickled internal document data without running tests; Can't be used with --section or --reload.",
     )
     parser.add_argument(
         "--reload",
         "-r",
         dest="reload",
         action="store_true",
-        help="reload LaTeX pickled internal data, before possibly adding to it",
-    )
-    parser.add_argument(
-        "--tex",
-        "-t",
-        dest="tex",
-        action="store_true",
-        help="include LaTeX document generation file at the end of other steps",
+        help="reload pickled internal document data, before possibly adding to it",
     )
     parser.add_argument(
         "--quiet", "-q", dest="quiet", action="store_true", help="hide passed tests"
@@ -532,6 +534,9 @@ def main():
         default=MAX_TESTS,
         help="run only  N tests",
     )
+
+    global logfile
+
     args = parser.parse_args()
 
     if args.enlapsed_times:
@@ -547,7 +552,10 @@ def main():
             documentation.load_pymathics_doc()
 
         test_sections(
-            sections, stop_on_failure=args.stop_on_failure, reload=args.reload
+            sections,
+            stop_on_failure=args.stop_on_failure,
+            generate_output=args.output,
+            reload=args.reload,
         )
     elif args.chapters:
         chapters = set(args.chapters.split(","))
@@ -562,8 +570,6 @@ def main():
         if args.pymathics:
             print("Building pymathics documentation object")
             documentation.load_pymathics_doc()
-        elif args.latex_only:
-            write_latex()
         elif args.doc_only:
             extract_doc_from_source(
                 quiet=args.quiet,
@@ -584,9 +590,6 @@ def main():
             )
             end_time = datetime.now()
             print("Tests took ", end_time - start_time)
-    # If TeX output requested, try to build it:
-    if args.tex:
-        write_latex()
     if logfile:
         logfile.close()
 
