@@ -14,6 +14,7 @@ definitions = Definitions(add_builtin=True)
 def prepare():
     pass
 
+
 result = None
 
 
@@ -30,20 +31,21 @@ def run():
         #     'Plus@@f/@Symbol/@StringJoin/@Tuples[CharacterRange["a","z"],2]')
         # prompt = 'FullForm[Nest[1+Sqrt[1+#]&, x, 20]]'
         # prompt = '1+2'
-        prompt = 'DensityPlot[x*y,{x,-1,1},{y,-1,1}]'
-        evaluation = Evaluation(definitions, format='xml')
+        prompt = "DensityPlot[x*y,{x,-1,1},{y,-1,1}]"
+        evaluation = Evaluation(definitions, format="xml")
         result = evaluation.parse_evaluate(prompt)
     except KeyboardInterrupt:
-        result = 'INTERRUPTED'
+        result = "INTERRUPTED"
 
 
 def _profile():
     global result
     prepare()
-    cProfile.run('run()', 'profile')
-    p = pstats.Stats('profile')
-    p.sort_stats('cumulative').print_stats(50)
+    cProfile.run("run()", "profile")
+    p = pstats.Stats("profile")
+    p.sort_stats("cumulative").print_stats(50)
     p.print_callees(20)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     _profile()
