@@ -4,18 +4,22 @@ from mathics.session import MathicsSession
 
 session = MathicsSession(add_builtin=True, catch_interrupt=False)
 
+
 def evaluate_value(str_expr: str):
     return session.evaluate(str_expr).value
 
+
 def evaluate(str_expr: str):
     return session.evaluate(str_expr)
 
+
 def check_evaluation(
     str_expr: str,
     str_expected: str,
     message="",
     to_string_expr=True,
     to_string_expected=True,
+    to_python_expected=False,
 ):
     """Helper function to test Mathics expression against
     its results"""
@@ -30,6 +34,8 @@ def check_evaluation(
         expected = evaluate_value(str_expected)
     else:
         expected = evaluate(str_expr)
+        if to_python_expected:
+            expected = expected.to_python(string_quotes=False)
 
     print(time.asctime())
     if message:
