@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from .helper import check_evaluation, evaluate
 
+
 def test_catch():
     evaluate(
         """
@@ -95,3 +96,17 @@ def test_condition():
         ),
     ):
         check_evaluation(str_expr, str_expected, message)
+
+
+def test_full_form():
+    for str_expr, str_expected in (
+        ("FullForm[Hold[a ;]]", "Hold[CompoundExpression[a, Null]]"),
+        ("FullForm[Hold[a ; b]]", "Hold[CompoundExpression[a, b]]"),
+        ("FullForm[Hold[a ; b ;]]", "Hold[CompoundExpression[a, b, Null]]"),
+        ("FullForm[Hold[a ; b ; c]]", "Hold[CompoundExpression[a, b, c]]"),
+        ("FullForm[Hold[a ; ; c]]", "Hold[CompoundExpression[a, Null, c]]"),
+        ("FullForm[Hold[a ; ;]]", "Hold[CompoundExpression[a, Null, Null]]"),
+    ):
+        check_evaluation(
+            str_expr, str_expected, to_string_expected=False, to_python_expected=True
+        )
